@@ -21,6 +21,7 @@
 import argparse
 import base64
 import configparser
+import difflib
 import gzip
 import io
 import json
@@ -35,10 +36,17 @@ import sys
 import tempfile
 import textwrap
 import zipfile
-from distutils.version import LooseVersion
 from pathlib import Path
 from urllib.parse import urlparse
 
+try:
+    from looseversion import LooseVersion
+except ImportError:
+    # distutils.version was removed in Python 3.12
+    from distutils.version import LooseVersion
+    import warnings
+
+    warnings.filterwarnings("ignore", category=DeprecationWarning)
 
 COMPATIBLE_VERSION = '26.1.1'
 
@@ -1005,6 +1013,13 @@ def install(to_install, android_home=None):
         to_install = [to_install]
     for package in to_install:
         key = tuple(package.split(';'))
+        if key not in packages:
+            print("""Warning: Failed to find package '%s'""" % package)
+            package_names = [';'.join(n) for n in packages]
+            m = difflib.get_close_matches(package, package_names, 1)
+            if m:
+                print("""Did you mean '%s'?""" % m[0])
+            sys.exit(1)
         url = packages[key]
 
         if key[0] == 'extras' and len(key) in (3, 4):
